@@ -57,7 +57,7 @@ struct _helpWindow {
     GtkWidget *entryBox;
 
     /* status bar */
-    GtkWidget *statusBar;
+    GtkWidget *appBar;
 
     /* Bogus widgets used by accel table */
     GtkWidget *accelWidget;
@@ -125,39 +125,33 @@ XmImageInfo *load_image(GtkWidget *html_widget, gchar *ref);
 /* Menu and toolbar structures */
 
 GnomeUIInfo filemenu[] = {
-	{ GNOME_APP_UI_ITEM, N_("_New window"), N_("Open new browser window"), new_window_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', GDK_CONTROL_MASK, NULL },
-	 
+        GNOMEUIINFO_MENU_NEW_ITEM(N_("_New Window"),
+				     N_("Open new browser window"),
+				     new_window_cb, NULL),
+
+	GNOMEUIINFO_SEPARATOR,
+
 	{GNOME_APP_UI_ITEM, 
 	 N_("_Add Bookmark"), N_("Add bookmark"),
          bookmark_cb, NULL, NULL, 
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
 	 0, 0, NULL},
 
-	{ GNOME_APP_UI_ITEM, N_("P_references..."), N_("Preferences"), config_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 0, 0, NULL },
-	 
-	{GNOME_APP_UI_ITEM, 
-	 N_("_Close"), N_("Close window"),
-         close_cb, NULL, NULL, 
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
-	 'w', GDK_CONTROL_MASK, NULL},
-	{GNOME_APP_UI_ITEM, 
-	 N_("E_xit"), N_("Exit all windows"),
-         quit_cb, NULL, NULL, 
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT,
-	 'x', GDK_CONTROL_MASK, NULL},
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_MENU_CLOSE_ITEM(close_cb, NULL),
+
+	GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb, NULL),
+
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo helpmenu[] = {
-    {GNOME_APP_UI_ITEM, 
-     N_("_About"), N_("Info about this program"),
-     about_cb, NULL, NULL, 
-     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
-     0, 0, NULL},
-    GNOMEUIINFO_SEPARATOR,
+  
     GNOMEUIINFO_HELP("help-browser"),
+
+    GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
+
     GNOMEUIINFO_END
 };
  
@@ -175,10 +169,16 @@ GnomeUIInfo windowmenu[] = {
 	 GNOMEUIINFO_END
 };
 
+GnomeUIInfo settingsmenu[] = {
+        GNOMEUIINFO_MENU_PREFERENCES_ITEM(config_cb, NULL),
+	GNOMEUIINFO_END
+};
+
 GnomeUIInfo mainmenu[] = {
-    GNOMEUIINFO_SUBTREE(N_("_File"), filemenu),
+    GNOMEUIINFO_MENU_FILE_TREE(filemenu),
     GNOMEUIINFO_SUBTREE(N_("_Window"), windowmenu),
-    GNOMEUIINFO_SUBTREE(N_("_Help"), helpmenu),
+    GNOMEUIINFO_MENU_SETTINGS_TREE(settingsmenu),
+    GNOMEUIINFO_MENU_HELP_TREE(helpmenu),
     GNOMEUIINFO_END
 };
 
@@ -286,9 +286,9 @@ xmhtml_activate(GtkWidget *w, XmHTMLAnchorCallbackStruct *cbs, HelpWindow win)
 static void
 anchorTrack(GtkWidget *w, XmHTMLAnchorCallbackStruct *cbs, HelpWindow win)
 {
-	gtk_statusbar_pop(GTK_STATUSBAR(win->statusBar), 1);
+	gnome_appbar_pop(GNOME_APPBAR(win->appBar));
 	if (cbs->href) {
-		gtk_statusbar_push(GTK_STATUSBAR(win->statusBar),1,cbs->href);
+		gnome_appbar_push(GNOME_APPBAR(win->appBar), cbs->href);
 	}
 }
 
@@ -710,9 +710,12 @@ helpWindowNew(gchar *name,
 	gtk_widget_show(w->helpWidget);
 
 	/* add a status bar */
-	w->statusBar = gtk_statusbar_new();
-	gtk_widget_show(w->statusBar);
+	w->appBar = gnome_appbar_new(FALSE, TRUE,
+				     GNOME_PREFERENCES_USER);
 
+	gnome_app_set_statusbar(GNOME_APP(w->app), GTK_WIDGET(w->appBar));
+	gnome_app_install_menu_hints(GNOME_APP (w->app), mainmenu);
+	
 	/* trap clicks on tags so we can stick requested link in browser */
 	gtk_signal_connect(GTK_OBJECT(w->helpWidget), "activate",
 			   GTK_SIGNAL_FUNC(xmhtml_activate), w);
@@ -724,7 +727,7 @@ helpWindowNew(gchar *name,
 					     GTK_SIGNAL_FUNC(formActivate), w);
 
 	gtk_box_pack_start(GTK_BOX(vbox), w->helpWidget, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), w->statusBar, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), w->appBar, FALSE, FALSE, 0);
 	gnome_app_set_contents(GNOME_APP(w->app), vbox);
 
 	/* HACKHACKHACK this will grab images via http */
@@ -818,7 +821,7 @@ helpWindowShowURL(HelpWindow win, gchar *ref,
 		return;
 	} else {
 		/* clear the status bar */
-		gtk_statusbar_pop(GTK_STATUSBAR(win->statusBar), 1);
+		gnome_appbar_pop(GNOME_APPBAR(win->appBar));
 	}
 	update_toolbar(win);
 	setCurrent(win);
