@@ -38,15 +38,15 @@ typedef void (*VoidSignal) (GtkObject * object,
 static GList *buttons=NULL;
 
 /*the tiles go here*/
-static GdkPixmap *tiles_up[LAST_TILE]={NULL,NULL,NULL};
-static GdkBitmap *tiles_up_mask[LAST_TILE]={NULL,NULL,NULL};
-static GdkPixmap *tiles_down[LAST_TILE]={NULL,NULL,NULL};
-static GdkBitmap *tiles_down_mask[LAST_TILE]={NULL,NULL,NULL};
-static int tile_border[LAST_TILE]={0,0,0};
-static int tile_depth[LAST_TILE]={0,0,0};
+static GdkPixmap *tiles_up[LAST_TILE]={NULL,NULL,NULL,NULL};
+static GdkBitmap *tiles_up_mask[LAST_TILE]={NULL,NULL,NULL,NULL};
+static GdkPixmap *tiles_down[LAST_TILE]={NULL,NULL,NULL,NULL};
+static GdkBitmap *tiles_down_mask[LAST_TILE]={NULL,NULL,NULL,NULL};
+static int tile_border[LAST_TILE]={0,0,0,0};
+static int tile_depth[LAST_TILE]={0,0,0,0};
 
 /*are tiles enabled*/
-static int tiles_enabled[LAST_TILE]={FALSE,FALSE,FALSE};
+static int tiles_enabled[LAST_TILE]={FALSE,FALSE,FALSE,FALSE};
 
 static GtkWidgetClass *parent_class;
 
@@ -291,9 +291,8 @@ button_widget_draw(ButtonWidget *button, GdkPixmap *pixmap)
 {
 	GtkWidget *widget = GTK_WIDGET(button);
 	GtkWidget *pwidget;
-	GdkPixmap *tile;
-	GdkBitmap *tile_mask;
-	GdkPoint points[3];
+	GdkPixmap *tile = NULL;
+	GdkBitmap *tile_mask = NULL;
 	GdkGC *gc;
 	/*offset for pressed buttons*/
 	int off = button->in_button&&button->pressed?tile_depth[button->tile]:0;
@@ -308,15 +307,6 @@ button_widget_draw(ButtonWidget *button, GdkPixmap *pixmap)
 	
 	gc = gdk_gc_new(pixmap);
 
-	if(button->arrow) {
-		int i;
-		draw_arrow(points,button->orient);
-		for(i=0;i<3;i++) {
-			points[i].x+=widget->allocation.x+off;
-			points[i].y+=widget->allocation.y+off;
-		}
-	}
-	
 	if(tiles_enabled[button->tile]) {
 		if(button->pressed && button->in_button) {
 			tile = tiles_down[button->tile];
@@ -364,6 +354,13 @@ button_widget_draw(ButtonWidget *button, GdkPixmap *pixmap)
 	}
 	
 	if(button->arrow) {
+		int i;
+		GdkPoint points[3];
+		draw_arrow(points,button->orient);
+		for(i=0;i<3;i++) {
+			points[i].x+=widget->allocation.x+off;
+			points[i].y+=widget->allocation.y+off;
+		}
 		gdk_gc_set_foreground(gc,&pwidget->style->white);
 		gdk_draw_polygon(pixmap,gc,TRUE,points,3);
 		gdk_gc_set_foreground(gc,&pwidget->style->black);
@@ -561,6 +558,7 @@ static void
 loadup_file(GdkPixmap **pixmap, GdkBitmap **mask, char *file)
 {
 	GdkImlibImage *im = NULL;
+	int w,h;
 
 	if(*file!='/') {
 		char *f;
@@ -577,7 +575,22 @@ loadup_file(GdkPixmap **pixmap, GdkBitmap **mask, char *file)
 		return;
 	}
 
-	gdk_imlib_render (im, BIG_ICON_SIZE, BIG_ICON_SIZE);
+	w = im->rgb_width;
+	h = im->rgb_height;
+	if(w>h) {
+		if(w>BIG_ICON_SIZE) {
+			h = h*((double)BIG_ICON_SIZE/w);
+			w = BIG_ICON_SIZE;
+		}
+	} else {
+		if(h>BIG_ICON_SIZE) {
+			w = w*((double)BIG_ICON_SIZE/h);
+			h = BIG_ICON_SIZE;
+		}
+	}
+	w = w>0?w:1;
+	h = h>0?h:1;
+	gdk_imlib_render (im, w, h);
 
 	*pixmap = gdk_imlib_copy_image (im);
 	*mask = gdk_imlib_copy_mask (im);
