@@ -19,12 +19,14 @@ struct _Extern {
 	char *goad_id;
 	char *cfg;
 	GtkWidget *ebox;
+	int started;
 
 	AppletInfo *info;
 };
 void extern_clean(Extern *ext);
 
-void load_extern_applet(char *goad_id, char *cfgpath, PanelWidget *panel, int pos);
+void load_extern_applet(char *goad_id, char *cfgpath, PanelWidget *panel, int pos, int queue);
+void load_queued_externs(void);
 
 void panel_corba_clean_up(void);
 void panel_corba_gtk_init(CORBA_ORB panel_orb);
