@@ -205,6 +205,7 @@ add_drawers_from_dir(char *dirname, char *name, int pos, PanelWidget *panel)
 	for(li = list; li!= NULL; li = g_slist_next(li)) {
 		char *filename = g_concat_dir_and_file(dirname, li->data);
 		struct stat s;
+		g_free(li->data);
 		if (stat (filename, &s) == 0) {
 			if (S_ISDIR (s.st_mode)) {
 				add_drawers_from_dir(filename,NULL,INT_MAX/2,
@@ -220,7 +221,6 @@ add_drawers_from_dir(char *dirname, char *name, int pos, PanelWidget *panel)
 			}
 		}
 		g_free(filename);
-		g_free(li->data);
 	}
 	g_slist_free(list);
 }
@@ -343,13 +343,6 @@ edit_dentry(GtkWidget *widget, char *item_loc)
 	gnome_desktop_entry_free(dentry);
 }
 
-static void
-destroy_dedit(GtkObject *dedit,gpointer data)
-{
-	char *s = gtk_object_get_data(dedit,"location");
-	g_free(s);
-}
-
 static void
 edit_direntry(GtkWidget *widget, MenuFinfo *mf)
 {
@@ -367,7 +360,9 @@ edit_direntry(GtkWidget *widget, MenuFinfo *mf)
 	dentry = gnome_desktop_entry_load_unconditional(dirfile);
 	if (dentry) {
 		gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(o), dentry);
-		gtk_object_set_data(o,"location",g_strdup(dentry->location));
+		gtk_object_set_data_full(o,"location",
+					 g_strdup(dentry->location),
+					 (GtkDestroyNotify)g_free);
 		gnome_desktop_entry_destroy(dentry);
 		g_free(dirfile);
 	} else {
@@ -377,7 +372,8 @@ edit_direntry(GtkWidget *widget, MenuFinfo *mf)
 		dentry->type = g_strdup("Directory");
 		/*we don't have to free dirfile here it will be freed as if
 		  we had strduped it here*/
-		gtk_object_set_data(o,"location",dirfile);
+		gtk_object_set_data_full(o,"location",dirfile,
+					 (GtkDestroyNotify)g_free);
 		gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(o), dentry);
 		gnome_desktop_entry_destroy(dentry);
 	}
@@ -391,7 +387,6 @@ edit_direntry(GtkWidget *widget, MenuFinfo *mf)
 	gtk_signal_connect_object(o, "changed",
 				  GTK_SIGNAL_FUNC(gnome_property_box_changed),
 				  GTK_OBJECT(dialog));
-	gtk_signal_connect(o, "destroy", GTK_SIGNAL_FUNC(destroy_dedit),NULL);
 
 	gtk_signal_connect(GTK_OBJECT(dialog), "apply",
 			   GTK_SIGNAL_FUNC(dentry_apply_callback),
@@ -841,8 +836,7 @@ add_menu_separator (GtkWidget *menu)
 static int
 add_drawer_to_panel (GtkWidget *widget, void *data)
 {
-	load_drawer_applet(-1,NULL,NULL,
-			   current_panel, 0);
+	load_drawer_applet(-1,NULL,NULL, current_panel, 0);
 	return TRUE;
 }
 
@@ -853,7 +847,7 @@ add_logout_to_panel (GtkWidget *widget, void *data)
 	return TRUE;
 }
 
-static int
+static void
 add_applet (GtkWidget *w, char *item_loc)
 {
 	GnomeDesktopEntry *ii = gnome_desktop_entry_load(item_loc);
@@ -862,13 +856,11 @@ add_applet (GtkWidget *w, char *item_loc)
 	
 	if(!goad_id) {
 		g_warning(_("Can't get goad_id from desktop entry!"));
-		return TRUE;
+		return;
 	}
-	load_extern_applet(goad_id,NULL,current_panel,0);
+	load_extern_applet(goad_id,NULL,current_panel,0,FALSE);
 
 	g_free(goad_id);
-
-	return TRUE;
 }
 
 static int
@@ -961,125 +953,120 @@ static GtkWidget * create_menu_at (GtkWidget *menu,
 				   int force);
 static void create_rh_menu(void);
 
-/*if menu is NULL that means just reread the menu don't do anything with the
-  applet*/
-static GtkWidget *
-check_and_reread(GtkWidget *menuw,Menu *menu,int main_menu)
+/*reread the applet menu, not a submenu*/
+static void
+check_and_reread_applet(Menu *menu,int main_menu)
 {
-	/*we are creating a whole new menuf or an applet if menu isn't NULL*/
-	if(menu) {
-		GSList *mfl = gtk_object_get_data(GTK_OBJECT(menuw), "mf");
-		GSList *list;
-		int need_reread = FALSE;
-		
-		/*we shouldn't warn, this is more for debugging anyway,
-		  and nowdays we do have menus that don't have one, this
-		  however might be needed for further debugging*/
-		/*if(!mfl)
-			g_warning("Weird menu doesn't have mf entry");*/
+	GSList *mfl = gtk_object_get_data(GTK_OBJECT(menu->menu), "mf");
+	GSList *list;
+	int need_reread = FALSE;
 
-		/*check if we need to reread this*/
-		for(list = mfl; list != NULL; list = g_slist_next(list)) {
-			MenuFinfo *mf = list->data;
-			if(mf->fake_menu ||
-			   !check_finfo_list(mf->finfo)) {
-				need_reread = TRUE;
-				break;
-			}
+	/*we shouldn't warn, this is more for debugging anyway,
+	  and nowdays we do have menus that don't have one, this
+	  however might be needed for further debugging*/
+	/*if(!mfl)
+	  g_warning("Weird menu doesn't have mf entry");*/
+
+	/*check if we need to reread this*/
+	for(list = mfl; list != NULL; list = g_slist_next(list)) {
+		MenuFinfo *mf = list->data;
+		if(mf->fake_menu ||
+		   !check_finfo_list(mf->finfo)) {
+			need_reread = TRUE;
+			break;
 		}
+	}
 
-		if(need_reread) {
-			if(main_menu)
-				add_menu_widget(menu,NULL,main_menu,TRUE);
-			else {
-				GSList *dirlist = NULL;
-				for(list = mfl; list != NULL;
-				    list = g_slist_next(list)) {
-					MenuFinfo *mf = list->data;
-					dirlist = g_slist_append(dirlist,
-								 mf->menudir);
-				}
-				add_menu_widget(menu,dirlist, main_menu,TRUE);
-				g_slist_free(dirlist);
-			}
-
-			gtk_widget_destroy(menuw);
-		}
-	} else {
-		GSList *mfl = gtk_object_get_data(GTK_OBJECT(menuw), "mf");
-		GSList *list;
-		int need_reread = FALSE;
-		int all_fake = TRUE;
-		
-		/*if(!mfl)
-			g_warning("Weird menu doesn't have mf entry");*/
-
-		/*check if we need to reread this*/
-		for(list = mfl; list != NULL; list = g_slist_next(list)) {
-			MenuFinfo *mf = list->data;
-			if(!mf->fake_menu)
-				all_fake = FALSE;
-			if(!need_reread &&
-			   (mf->fake_menu || !check_finfo_list(mf->finfo))) {
-				need_reread = TRUE;
-
-			}
-		}
-		if(need_reread) {
-			GtkWidget *old_menu = NULL;
-			GSList *free_list = NULL;
-			/*we are all fake so we want to use the previous
-			  menu widget*/
-			if(all_fake) {
-				old_menu = menuw;
-				gtk_object_set_data(GTK_OBJECT(old_menu), "mf",
-						    NULL);
-				/*set this so that we free it after we use it,
-				  since it won't be freed during the
-				  destruction of the menu since there will
-				  be none*/
-				free_list = mfl;
-			}
+	if(need_reread) {
+		/*that will be destroyed in add_menu_widget*/
+		if(main_menu)
+			add_menu_widget(menu,NULL,main_menu,TRUE);
+		else {
+			GSList *dirlist = NULL;
 			for(list = mfl; list != NULL;
 			    list = g_slist_next(list)) {
 				MenuFinfo *mf = list->data;
-				menuw = create_menu_at(old_menu,
-						       mf->menudir,
-						       mf->applets,
-						       mf->dir_name,
-						       mf->pixmap_name,
-						       TRUE,
-						       FALSE);
-				old_menu = menuw;
+				dirlist = g_slist_append(dirlist,
+							 mf->menudir);
 			}
-			/*free up stuff that won't be freed somewhere else*/
-			for(list = free_list; list != NULL;
-			    list = g_slist_next(list)) {
-				MenuFinfo *mf = list->data;
-				destroy_mf(mf);
-			}
-			g_slist_free(free_list);
+			add_menu_widget(menu,dirlist, main_menu,TRUE);
+			g_slist_free(dirlist);
 		}
 	}
-	return menuw;
+}
+
+static int
+sel_idle(gpointer data)
+{
+	gtk_item_select(GTK_ITEM(data));
+	return FALSE;
 }
 
 static void
 submenu_to_display(GtkMenuItem *menuitem, gpointer data)
 {
-	GtkWidget *menu = check_and_reread(menuitem->submenu,
-					   NULL,FALSE);
-	g_return_if_fail(menu!=NULL);
+	GtkWidget *menuw = menuitem->submenu;
+	GSList *mfl = gtk_object_get_data(GTK_OBJECT(menuw), "mf");
+	GSList *list;
+	int need_reread = FALSE;
+
+	/*if(!mfl)
+	  g_warning("Weird menu doesn't have mf entry");*/
+
+	/*check if we need to reread this*/
+	for(list = mfl; list != NULL; list = g_slist_next(list)) {
+		MenuFinfo *mf = list->data;
+		if(!need_reread &&
+		   (mf->fake_menu || !check_finfo_list(mf->finfo))) {
+			need_reread = TRUE;
+
+		}
+	}
 	/*THIS IS A HACK, but a cool one at that*/
-	if(menu!=menuitem->submenu) {
+	if(need_reread) {
+		int was_visible = GTK_WIDGET_VISIBLE(menuw);
+		/*prevent the mfl from being destroyed now*/
+		gtk_object_set_data(GTK_OBJECT(menuw), "mf",NULL);
+		gtk_widget_destroy(menuw);
+		menuw = NULL;
+		for(list = mfl; list != NULL;
+		    list = g_slist_next(list)) {
+			GSList *li;
+			MenuFinfo *mf = list->data;
+
+			/*mem efficency hack, free this since we'll
+			  be creating such a list again at create_menu_at
+			  so we'd use this memory instead of allocationg
+			  more*/
+			for(li=mf->finfo;li!=NULL;li=g_slist_next(li)) {
+				FileInfo *fi = li->data;
+				g_free(fi->name);
+				g_free(fi);
+			}
+			g_slist_free(mf->finfo);
+			mf->finfo = NULL;
+
+			menuw = create_menu_at(menuw,
+					       mf->menudir,
+					       mf->applets,
+					       mf->dir_name,
+					       mf->pixmap_name,
+					       TRUE,
+					       FALSE);
+			destroy_mf(mf);
+		}
+		g_slist_free(mfl);
+
 		/*it's not yet displayed we're ok here*/
-		if(!GTK_WIDGET_VISIBLE(menuitem->submenu))
-			gtk_menu_item_set_submenu (GTK_MENU_ITEM(menuitem), menu);
-		/*now is when the fun begins, we kill the menu and do select
-		  again ... nowdays, we'll be ok though*/
-		else {
-			gtk_widget_destroy(menuitem->submenu);
-			gtk_menu_item_set_submenu (GTK_MENU_ITEM(menuitem), menu);
+		if(!was_visible) {
+			gtk_menu_item_set_submenu (GTK_MENU_ITEM(menuitem),
+						   menuw);
+		/*now we have to select again as this is already messed up*/
+		} else {
+			gtk_signal_emit_stop_by_name(GTK_OBJECT(menuitem),
+						     "select");
+			gtk_menu_item_set_submenu (GTK_MENU_ITEM(menuitem),
+						   menuw);
 			gtk_item_select(GTK_ITEM(menuitem));
 		}
 	}
@@ -1131,6 +1118,133 @@ create_fake_menu_at (char *menudir,
 	return menu;
 }
 
+static GSList *
+create_menuitem(GtkWidget *menu,
+		char *menudir,
+		char *thisfile,
+		int applets,
+		int fake_submenus,
+		int *items,
+		int *add_separator,
+		int *first_item,
+		GSList *finfo)
+{
+	GnomeDesktopEntry *item_info=NULL;
+	FileInfo *fi;
+	GtkWidget *menuitem, *sub, *pixmap;
+	char *pix_name;
+	char *menuitem_name;
+	char *filename;
+	struct stat s;
+
+	filename = g_strconcat(menudir,"/",thisfile, NULL);
+
+	if (stat (filename, &s) == -1) {
+		g_warning("Something is wrong, "
+			  "file %s can't be stated",
+			  filename);
+		/* make sure that we free up the filename before returning. */
+		g_free(filename);
+		return finfo;
+	}
+
+	sub = NULL;
+	item_info = NULL;
+	if (S_ISDIR (s.st_mode)) {
+		char *p;
+		p = g_strconcat(filename,"/.directory",NULL);
+		item_info = gnome_desktop_entry_load (p);
+
+		/*add the .directory file to the checked files list*/
+		fi = make_finfo(p,TRUE);
+		finfo = g_slist_prepend(finfo,fi);
+
+		menuitem_name = item_info?item_info->name:thisfile;
+		pix_name = item_info?item_info->icon:NULL;
+
+		if(fake_submenus)
+			sub = create_fake_menu_at (filename,
+						   applets,
+						   menuitem_name,
+						   pix_name);
+		else
+			sub = create_menu_at (NULL, filename, 
+					      applets,
+					      menuitem_name,
+					      pix_name,
+					      fake_submenus,
+					      FALSE);
+
+		if (!sub) {
+			if(item_info)
+				gnome_desktop_entry_free(item_info);
+			/* free up the string allocated at the top of this block */
+			g_free(p);
+			return finfo;
+		}
+		/* free up the pointer at the top of this block. */
+		g_free(p);
+	} else {
+		char *p = strrchr(filename,'.');
+		if (!p || strcmp(p, ".desktop") != 0)
+			return finfo;
+		item_info = gnome_desktop_entry_load (filename);
+		if (!item_info)
+			return finfo;
+		menuitem_name = item_info->name;
+		pix_name = item_info->icon;
+
+		/*add file to the checked files list*/
+		fi = make_finfo_s(filename,&s);
+		finfo = g_slist_prepend(finfo,fi);
+	}
+
+	(*items)++;
+
+	menuitem = gtk_menu_item_new ();
+	if (sub) {
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM(menuitem), sub);
+		gtk_signal_connect(GTK_OBJECT(menuitem),"select",
+				   GTK_SIGNAL_FUNC(submenu_to_display),
+				   NULL);
+	}
+
+	pixmap = NULL;
+	if (pix_name && g_file_exists (pix_name)) {
+		pixmap = gnome_stock_pixmap_widget_at_size (NULL, pix_name,
+							    SMALL_ICON_SIZE,
+							    SMALL_ICON_SIZE);
+		if (pixmap)
+			gtk_widget_show (pixmap);
+	}
+
+	if(!sub && applets)
+		setup_applet_drag (menuitem, item_info);
+	/*setup the menuitem, pass item_loc if this is not
+	  a submenu or an applet, so that the item can be added,
+	  we can be sure that the finfo will live that long*/
+	setup_full_menuitem (menuitem, pixmap, menuitem_name,
+			     (applets||sub)?NULL:fi->name);
+
+	if(*add_separator) {
+		add_menu_separator(menu);
+		(*first_item)++;
+		*add_separator = FALSE;
+	}
+	gtk_menu_append (GTK_MENU (menu), menuitem);
+
+	if(item_info && item_info->exec) {
+		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+				    applets?
+				    GTK_SIGNAL_FUNC(add_applet):
+				    GTK_SIGNAL_FUNC(activate_app_def),
+				    fi->name);
+	}
+	if(item_info)
+		gnome_desktop_entry_free(item_info);
+	return finfo;
+}
+
 static GtkWidget *
 create_menu_at (GtkWidget *menu,
 		char *menudir,
@@ -1140,37 +1254,31 @@ create_menu_at (GtkWidget *menu,
 		int fake_submenus,
 		int force)
 {	
-	GnomeDesktopEntry *item_info=NULL;
 	GnomeDesktopEntry *dir_info=NULL;
-	struct stat s;
 	char *filename;
 	int items = 0;
 	FileInfo *fi;
 	GSList *finfo = NULL;
 	GSList *flist = NULL;
-	GSList *li = NULL;
 	GSList *mfl = NULL;
 	int add_separator = FALSE;
 	int first_item = 0;
 	GtkWidget *menuitem;
-	char *dentry_name;
 	
 	MenuFinfo *mf = NULL;
 	
 	if(!force && !g_file_exists(menudir))
 		return menu;
 	
-	dentry_name = g_concat_dir_and_file (menudir,
-					     ".directory");
-	dir_info = gnome_desktop_entry_load (dentry_name);
+	filename = g_strconcat(menudir,"/.directory",NULL);
+	dir_info = gnome_desktop_entry_load (filename);
 
 	/*add the .directory file to the checked files list,
 	  but only if we can stat it (if we can't it probably
 	  doesn't exist)*/
-	fi = make_finfo(dentry_name,FALSE);
+	fi = make_finfo(filename,FALSE);
 	if(fi)
 		finfo = g_slist_prepend(finfo,fi);
-	g_free (dentry_name);
 
 	/*get this info ONLY if we haven't gotten it already*/
 	if(!dir_name)
@@ -1189,11 +1297,12 @@ create_menu_at (GtkWidget *menu,
 	/*add the order file to the checked files list,
 	  but only if we can stat it (if we can't it probably doesn't
 	  exist)*/
-	filename = g_concat_dir_and_file(menudir,".order");
+	/* free up the old filename first */
+	g_free(filename);
+	filename = g_strconcat(menudir,"/.order",NULL);
 	fi = make_finfo(filename,FALSE);
 	if(fi)
 		finfo = g_slist_prepend(finfo,fi);
-	g_free(filename);
 
 	if(!menu) {
 		menu = gtk_menu_new ();
@@ -1208,127 +1317,18 @@ create_menu_at (GtkWidget *menu,
 
 	flist = get_files_from_menudir(menudir);
 	
-	for(li = flist; li != NULL; li = g_slist_next(li)) {
-		char *thisfile = li->data;
-		GtkWidget *sub, *pixmap;
-		char *pixmap_name;
-		char *menuitem_name;
-		
-		filename = g_concat_dir_and_file(menudir,thisfile);
-		
-		if (stat (filename, &s) == -1) {
-			g_warning("Something is wrong, "
-				  "file %s can't be stated",
-				  filename);
-			g_free (filename);
-			g_free(thisfile);
-			continue;
-		}
+	while(flist) {
+		char *thisfile = flist->data;
+		GSList *tmp = flist;
+		flist = g_slist_next(flist);
+		g_slist_free_1(tmp);
 
-		sub = NULL;
-		item_info = NULL;
-		if (S_ISDIR (s.st_mode)) {
-			dentry_name = g_concat_dir_and_file (filename,
-							     ".directory");
-			item_info = gnome_desktop_entry_load (dentry_name);
-
-			/*add the .directory file to the checked files list*/
-			fi = make_finfo(dentry_name,TRUE);
-			finfo = g_slist_prepend(finfo,fi);
-			g_free (dentry_name);
-
-			menuitem_name = item_info?item_info->name:thisfile;
-			pixmap_name = item_info?item_info->icon:NULL;
-
-			if(fake_submenus)
-				sub = create_fake_menu_at (filename,
-							   applets,
-							   menuitem_name,
-							   pixmap_name);
-			else
-				sub = create_menu_at (NULL, filename, 
-						      applets,
-						      menuitem_name,
-						      pixmap_name,
-						      fake_submenus,
-						      FALSE);
-
-			if (!sub) {
-				g_free(filename);
-				g_free(thisfile);
-				if(item_info)
-					gnome_desktop_entry_free(item_info);
-				continue;
-			}
-		} else {
-			char *p = strrchr(filename,'.');
-			if (!p || strcmp(p, ".desktop") != 0) {
-				g_free (filename);
-				g_free(thisfile);
-				continue;
-			}
-			item_info = gnome_desktop_entry_load (filename);
-			if (!item_info) {
-				g_free (filename);
-				g_free(thisfile);
-				continue;
-			}
-			menuitem_name = item_info->name;
-			pixmap_name = item_info->icon;
-			
-			/*add file to the checked files list*/
-			fi = make_finfo_s(filename,&s);
-			finfo = g_slist_prepend(finfo,fi);
-		}
-		
-		items++;
-		
-		menuitem = gtk_menu_item_new ();
-		if (sub) {
-			gtk_menu_item_set_submenu (GTK_MENU_ITEM(menuitem), sub);
-			gtk_signal_connect(GTK_OBJECT(menuitem),"select",
-					   GTK_SIGNAL_FUNC(submenu_to_display),
-					   NULL);
-		}
-
-		pixmap = NULL;
-		if (pixmap_name && g_file_exists (pixmap_name)) {
-			pixmap = gnome_stock_pixmap_widget_at_size (NULL, pixmap_name,
-								    SMALL_ICON_SIZE,
-								    SMALL_ICON_SIZE);
-			if (pixmap)
-				gtk_widget_show (pixmap);
-		}
-		
-		if(!sub && applets)
-			setup_applet_drag (menuitem, item_info);
-		/*setup the menuitem, pass item_loc if this is not
-		  a submenu or an applet, so that the item can be added,
-		  we can be sure that the finfo will live that long*/
- 		setup_full_menuitem (menuitem, pixmap, menuitem_name,
-				     (applets||sub)?NULL:fi->name);
-
-		if(add_separator) {
-			add_menu_separator(menu);
-			first_item++;
-			add_separator = FALSE;
-		}
-		gtk_menu_append (GTK_MENU (menu), menuitem);
-
-		if(item_info && item_info->exec) {
-			gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-					    applets?
-					     GTK_SIGNAL_FUNC(add_applet):
-					     GTK_SIGNAL_FUNC(activate_app_def),
-					    fi->name);
-		}
-		if(item_info)
-			gnome_desktop_entry_free(item_info);
-
-		g_free(filename);
+		finfo = create_menuitem(menu,menudir,thisfile,
+					applets,fake_submenus,&items,
+					&add_separator,&first_item,
+					finfo);
 		g_free(thisfile);
 	}
-	g_slist_free(flist);
 	
 	mf = g_new(MenuFinfo,1);
 	mf->menudir = g_strdup(menudir);
@@ -1375,6 +1375,8 @@ create_menu_at (GtkWidget *menu,
 
 	gtk_object_set_data(GTK_OBJECT(menu),"mf",mfl);
 	
+	/* free up the filename from above. */
+	g_free(filename);
 	return menu;
 }
 
@@ -1853,6 +1855,13 @@ make_panel_submenu (GtkWidget *menu, int fake_submenus)
 			   (GtkSignalFunc) convert_to_panel,
 			   GINT_TO_POINTER(SNAPPED_PANEL));
 	gtk_object_set_data(GTK_OBJECT(menu),"convsnap",menuitem);
+
+	/*actually show hide right now to get the first size
+	  request correctly, still has a display problem when
+	  main menu is dragged onto a different type of a panel,
+	  but the problem is minimal (it only happens if the person
+	  uses the same menu)*/
+	show_x_on_panels(menu,NULL);
 	
 	gtk_signal_connect(GTK_OBJECT(menu),"show",
 			   GTK_SIGNAL_FUNC(show_x_on_panels),NULL);
@@ -1920,7 +1929,13 @@ make_panel_submenu (GtkWidget *menu, int fake_submenus)
 static void
 panel_lock (GtkWidget *widget, void *data)
 {
-	system ("(xscreensaver-command -activate&)");
+	gboolean lock = gnome_config_get_bool_with_default ("Screensaver/Default/password", FALSE);
+	/* we want to default to something safe.
+	 * Have we started xscreensaver in a locked state or not?*/
+	if (lock)
+		system ("(xscreensaver-command -activate&)");
+	else
+		system ("(xscreensaver-command -lock&)");
 }
 
 static void
@@ -2107,7 +2122,8 @@ add_redhat_entry(GSList *list, char *file)
 		p = buf;
 		g_free(read_word(&p)); /*XXX:ignore??*/
 		w = read_word(&p);
-		if(strcmp(w,"name")==0) {
+		if (!w) ;
+		else if(strcmp(w,"name")==0) {
 			g_free(rh->name);
 			rh->name = read_word(&p);
 		} else if(strcmp(w,"description")==0) {
@@ -2191,48 +2207,56 @@ make_rh_submenu(char *dir, GSList *rhlist)
 {
 	GSList *li;
 	FILE *fp;
-	char *order_file = g_concat_dir_and_file(dir,".order");
+	char *order_file;
+	order_file = g_strconcat(dir,"/",".order", NULL);
 	fp = fopen(order_file,"w");
 	for(li = rhlist;li!=NULL;li = g_slist_next(li)) {
 		RHMenuItem *ri = li->data;
 		GnomeDesktopEntry *dentry = g_new0(GnomeDesktopEntry,1);
-
-		dentry->name = g_strdup(ri->name);
+		dentry->name = ri->name;
 		if(ri->type == RH_MENU_GROUP) {
-			char *s = g_strdup(ri->name);
 			char *p;
-			dentry->type = g_strdup("Directory");
+			char *s;
+			s = g_strdup(ri->name);
+			dentry->type = "Directory";
 			while((p=strchr(s,' '))) *p='_';
-			p = g_concat_dir_and_file(dir,s);
+
+			p = g_strconcat(dir,"/",s, NULL);
 			if(fp) fprintf(fp,"%s\n",g_basename(p));
 			mkdir(p,0755);
-			dentry->location = g_concat_dir_and_file(p,".directory");
-			g_free(s);
+			dentry->location = g_strconcat(p,"/",".directory", NULL);
 			
 			make_rh_submenu(p,ri->u.items);
-
+			/* free up the strings */
+			g_free(s);
 			g_free(p);
 		} else {
-			char *s = g_strconcat(ri->name,".desktop",NULL);
 			char *p;
+			char *s;
+			s = g_strconcat(ri->name,".desktop",NULL);
 			while((p=strchr(s,' '))) *p='_';
 
-			dentry->type = g_strdup("Application");
-			dentry->comment = g_strdup(ri->u.item.description);
-			dentry->icon = g_strdup(ri->u.item.icon?
-						ri->u.item.icon:
-						ri->u.item.mini_icon);
+			dentry->type = "Application";
+			dentry->comment = ri->u.item.description;
+			dentry->icon = ri->u.item.icon?
+				ri->u.item.icon:
+				ri->u.item.mini_icon;
 			gnome_config_make_vector(ri->u.item.exec,
 						 &dentry->exec_length,
 						 &dentry->exec);
-			dentry->location = g_concat_dir_and_file(dir,s);
+			dentry->location = g_strconcat(dir,"/",s, NULL);
 			if(fp) fprintf(fp,"%s\n",s);
+			/* free up the location */
 			g_free(s);
 		}
 		gnome_desktop_entry_save(dentry);
-		gnome_desktop_entry_free(dentry);
+		if(dentry->exec) g_strfreev(dentry->exec);
+		/* free up the dentry at the top of this block */
+		g_free(dentry->location);
+		g_free(dentry);
 	}
 	if(fp) fclose(fp);
+	/* clean up the order_file from the top of the function */
 	g_free(order_file);
 }
 
@@ -2275,8 +2299,9 @@ create_rh_menu(void)
 			if(strcmp(dent->d_name,".")==0 ||
 			   strcmp(dent->d_name,"..")==0)
 				continue;
-			p = g_concat_dir_and_file(dirs[i],dent->d_name);
+			p = g_strconcat(dirs[i],dent->d_name,NULL);
 			rhlist = add_redhat_entry(rhlist,p);
+			/* free the list. */
 			g_free(p);
 		}
 		closedir(dir);
@@ -2286,12 +2311,15 @@ create_rh_menu(void)
 	if(rhlist) {
 		if (g_file_exists("/usr/share/icons/mini/mini-redhat.xpm")) {
 			GnomeDesktopEntry *dentry = g_new0(GnomeDesktopEntry,1);
-			dentry->name = g_strdup(_("Red Hat menus"));
-			dentry->type = g_strdup("Directory");
-			dentry->icon = g_strdup("/usr/share/icons/mini/mini-redhat.xpm");
-			dentry->location = g_concat_dir_and_file(rhdir,".directory");
+			dentry->name = _("Red Hat menus");
+			dentry->type = "Directory";
+			dentry->icon = "/usr/share/icons/mini/mini-redhat.xpm";
+			dentry->location = g_strconcat(rhdir,".directory",
+						       NULL);
 			gnome_desktop_entry_save(dentry);
-			gnome_desktop_entry_free(dentry);
+			/* free up the dentry + the location */
+			g_free(dentry->location);
+			g_free(dentry);
 		}
 		make_rh_submenu(rhdir,rhlist);
 
@@ -2394,6 +2422,8 @@ static void
 add_menu_widget (Menu *menu, GSList *menudirl, int main_menu, int fake_subs)
 {
 	GSList *li;
+	if(menu->menu)
+		gtk_widget_destroy(menu->menu);
 
 	if (main_menu)
 		menu->menu = create_root_menu(fake_subs, menu->main_menu_flags);
@@ -2418,6 +2448,9 @@ menu_button_pressed(GtkWidget *widget, gpointer data)
 					       "applet_info");
 	int main_menu = (strcmp (menu->path, ".") == 0);
 
+	/*this HAS to be set everytime we popup the menu*/
+	current_panel = PANEL_WIDGET(menu->button->parent);
+
 	if(!menu->menu) {
 		char *menu_base = gnome_unconditional_datadir_file ("apps");
 		char *this_menu = get_real_menu_path(menu->path,menu_base);
@@ -2434,7 +2467,7 @@ menu_button_pressed(GtkWidget *widget, gpointer data)
 		   !(menu->main_menu_flags&MAIN_MENU_REDHAT_SUB))
 			rh_submenu_to_display(NULL,NULL);
 
-		check_and_reread(menu->menu,menu,main_menu);
+		check_and_reread_applet(menu,main_menu);
 	}
 
 	/*so that the panel doesn't pop down until we're
@@ -2444,15 +2477,13 @@ menu_button_pressed(GtkWidget *widget, gpointer data)
 		snapped_widget_queue_pop_down(SNAPPED_WIDGET(wpanel));
 	}
 
-	/*this HAS to be set everytime we popup the menu*/
-	current_panel = PANEL_WIDGET(menu->button->parent);
-	
 	BUTTON_WIDGET(menu->button)->ignore_leave = TRUE;
 	gtk_grab_remove(menu->button);
 
 	menu->age = 0;
 	gtk_menu_popup(GTK_MENU(menu->menu), 0,0, applet_menu_position,
 		       info, bevent->button, bevent->time);
+	gdk_event_free((GdkEvent *)bevent);
 }
 
 static char *
@@ -2711,7 +2742,6 @@ add_menu_type_options(GtkObject *dialog, GtkTable *table, int row,
 	gtk_table_attach_defaults(table,w,3,4,row,row+1);
 	p = g_strconcat(ident,"_off",NULL);
 	gtk_object_set_data(dialog,p,w);
-	g_free(p);
 	if(!on)
 		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(w),TRUE);
 	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
@@ -2721,9 +2751,10 @@ add_menu_type_options(GtkObject *dialog, GtkTable *table, int row,
 	w = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(rb)),
 					     _("In a submenu"));
 	gtk_table_attach_defaults(table,w,2,3,row,row+1);
+	/* free it from above... */
+	g_free(p);
 	p = g_strconcat(ident,"_sub",NULL);
 	gtk_object_set_data(dialog,p,w);
-	g_free(p);
 	if(sub)
 		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(w),TRUE);
 	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
@@ -2738,6 +2769,8 @@ add_menu_type_options(GtkObject *dialog, GtkTable *table, int row,
 	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
 			    GTK_SIGNAL_FUNC (toggle_prop), 
 			    dialog);
+	/* free up "p" from above */
+	g_free(p);
 }
 	
 
