@@ -12,14 +12,16 @@ typedef enum {
 
 typedef struct {
 	GtkWidget *ebox;
-	GtkWidget *handle_n;
-	GtkWidget *handle_w;
+/* 	GtkWidget *handle_n; */
+/* 	GtkWidget *handle_w; */
 	GtkWidget *socket;
-	char *title;
+        GtkWidget *handle_box;
+        char *title;
 	char *path;
 	int width;
 	int height;
 	guint32 wid;
+	int timeout;
 } Swallow;
 
 void load_swallow_applet(char *path, char *params, int width, int height,
